@@ -2,7 +2,7 @@
 PicAssert图片断言工具：
 anchor： 测码范晔
 联系邮箱： 1538379200@qq.com
-当前版本：v 0.0.2
+当前版本：v 0.0.3
 通过图片拓展断言方式
 PicAsssert会将图片在全局做一次模板匹配行为，当查找的图片大于或者等于设置的阈值的时候，程序将返回True，
 当全局匹配的图片匹配度低于所设置的阈值时，程序将启动特征匹配模式，对前面相似度较近的区域进行截图，再次进行特征分析，
@@ -36,7 +36,10 @@ from SafeDriver.drivers import driver, option
 import time
 from PicAssert.Assert import Assert
 dr = driver()
-ps = Assert(dr)
+option.headless = True                  # 设置selenium无头模式
+dr.set_window_size(1920, 1080)          # 设置selenium浏览器窗口大小
+ps = Assert(dr)                         # 实例化Assert类
+ps.InitDPI = (1920, 1080)               # 设置当前设备分辨率
 dr.get("https://www.baidu.com")
 time.sleep(2)
 p1_res = ps.assert_exist(r"D:\test.png")     # ps.assert_exist(r"D:\test.png", 0.8)
@@ -78,6 +81,8 @@ class Assert:
         获取当前页面的截图，如果设置了driver，将使用selenium的截图方法
         :return: 图片路径名称
         """
+        if type(self.InitDPI) not in (list, tuple):
+            raise Exception("初始分辨率应为list或者tuple类型，且值类型应该为int")
         now_time = time.strftime("%Y%m%d%H%M%S")
         filename = "PICASSERT-" + now_time + ".png"
         filename = self.__cache_path + '/' + filename
